==> function-1.0.3.tgz: package/README.md <==


# ComputeTS: Function library
![](https://img.shields.io/npm/types/@compute.ts/boolean)
![](https://img.shields.io/npm/v/@compute.ts/boolean)
![](https://img.shields.io/npm/l/@compute.ts/boolean)
![](https://img.shields.io/badge/coverage-83,04%25-4cc41f.svg)
![](https://img.shields.io/badge/files-15-lightblue)
![](https://img.shields.io/badge/lines-1048-lightblue)
![](https://img.shields.io/badge/made%20in-France-blue)


## Presentation
The engine is based on incremental computation algorithms. When a calculation is submitted to the engine, all the computed values are memorized. So, if you change some variable and query an evaluation, the engine is able to compute the result very fast because it recomputes only what has changed.


## Libraries
The API provides several libraries that each comes with dozens of operators.
- [@compute.ts/boolean](https://www.npmjs.com/package/@compute.ts/boolean)
- [@compute.ts/number](https://www.npmjs.com/package/@compute.ts/number)
- [@compute.ts/string](https://www.npmjs.com/package/@compute.ts/string)
- [@compute.ts/date](https://www.npmjs.com/package/@compute.ts/date)
- [@compute.ts/dictionary](https://www.npmjs.com/package/@compute.ts/dictionary)
- [@compute.ts/array](https://www.npmjs.com/package/@compute.ts/array)
- [@compute.ts/math](https://www.npmjs.com/package/@compute.ts/math)
- [@compute.ts/structural](https://www.npmjs.com/package/@compute.ts/structural)



## Imports
### Typescript
```typescript
import {/* required operators */} from '@compute.ts/function';
```

### Javascript
```javascript
const {/* required operators */} = require('@compute.ts/function');
```

## Operators

### Function

<code>Function.take*Type*.return*Type*.code(value) ➜ x<sub>function</sub></code>  

The **Function** operator allows you to create an expression which evals to the result of the given fuction. If no value is provided the expression is a variable of the model

```typescript
import {Function} from "@compute.ts/function";

const x = Function
    .takeNumberArray
    .takeNumber
    .returnNumberArray
    .code((array: number[], threshold: number) => {
        return array.filter(value => value < threshold);
    });
```

* * *

### apply

<code>x<sub>function</sub>.apply(x<sub>type</sub>) ➜ x<sub>*type*</sub></code>

The **apply** operator allows to create a boolean expression which evals to the result of the function according to the value of the agument(s)

```typescript
import {Function} from "@compute.ts/function";
import {array} from "@compute.ts/array";
import {number} from "@compute.ts/number";

const x = Function
    .takeNumberArray
    .takeNumber
    .returnNumberArray
    .code((y1: number[], y2: number) => {
        return y1.filter(v => v < y2);
    });

const y1 = array.ofNumber([1, 2, 3, 4]);
const y2 = number();
const z = x.apply(y1, y2);

y2.affect(3)
const value = z.eval(); // [1, 2]
```

* * *

![](https://colibri-engine.com/assets/img/brand/logo_animated.gif)

==> function-2.0.1.tgz: package/README.md <==
![](https://colibri-engine.com/assets/img/compute.png)


![](https://img.shields.io/npm/types/@compute.ts/boolean)
![](https://img.shields.io/npm/v/@compute.ts/boolean)
![](https://img.shields.io/npm/l/@compute.ts/boolean)
![](https://img.shields.io/badge/coverage-73.73%25-4cc41f.svg)
![](https://img.shields.io/badge/files-15-orange)
![](https://img.shields.io/badge/lines-1534-orange)
![](https://img.shields.io/badge/made%20in-France-blue)


## Presentation
The engine is based on incremental computation algorithms. When a calculation is submitted to the engine, all the computed values are memorized. So, if you change some variable and query an evaluation, the engine is able to compute the result very fast because it recomputes only what has changed.


## Libraries
The project provides several libraries that each comes with dozens of operators. Please note the cross-compatibility of the libraries.
- [@compute.ts/boolean](https://www.npmjs.com/package/@compute.ts/boolean)
- [@compute.ts/number](https://www.npmjs.com/package/@compute.ts/number)
- [@compute.ts/string](https://www.npmjs.com/package/@compute.ts/string)
- [@compute.ts/date](https://www.npmjs.com/package/@compute.ts/date)
- [@compute.ts/dictionary](https://www.npmjs.com/package/@compute.ts/dictionary)
- [@compute.ts/array](https://www.npmjs.com/package/@compute.ts/array)
- [@compute.ts/math](https://www.npmjs.com/package/@compute.ts/math)
- [@compute.ts/structural](https://www.npmjs.com/package/@compute.ts/structural)



## Imports
### Typescript
```typescript
import {/* required operators */} from '@compute.ts/function';
```

### Javascript
```javascript
const {/* required operators */} = require('@compute.ts/function');
```

## Operators

### Function

<code>Function.take*Type*.return*Type*.code(value) ➜ x<sub>function</sub></code>  

The **Function** operator allows you to create an expression which evals to the result of the given fuction. If no value is provided the expression is a variable of the model

```typescript
import {Function} from "@compute.ts/function";

const x = Function
    .takeNumberArray
    .takeNumber
    .returnNumberArray
    .code((array: number[], threshold: number) => {
        return array.filter(value => value < threshold);
    });
```

* * *

### apply

<code>x<sub>function</sub>.apply(x<sup>0</sup><sub>type-A</sub>, x<sup>1</sup><sub>type-B</sub>, x<sup>2</sup><sub>type-C</sub>) ➜ x<sub>*type-return*</sub></code>

The **apply** operator allows to create a boolean expression which evals to the result of the function according to the value of the agument(s)

```typescript
import {Function} from "@compute.ts/function";
import {array} from "@compute.ts/array";
import {number} from "@compute.ts/number";

const x = Function
    .takeNumberArray
    .takeNumber
    .returnNumberArray
    .code((y1: number[], y2: number) => {
        return y1.filter(v => v < y2);
    });

const y1 = array.ofNumber([1, 2, 3, 4]);
const y2 = number();
const z = x.apply(y1, y2);

y2.affect(3)
const value = z.eval(); // [1, 2]
```


## About the author
I am a software developer with 4 years of project specializing in the development of web solutions. Digital Nomad, I work while traveling.  After 3 years into the french industry, I've started to work as a freelance software architect or fullstack developer.

Based on state-of-the-art web technologies, I offer you to architect & develop the best version of your project. My experience in the web app development assure you to build a nice looking, performant and stable product.

Minimalist, I like to travel, to meet people, learn new things and handmade stuff. Scuba & sky diving licenced. I like also hamburgers, Kinder chocolate and crepes. Karate black belt.

https://berthellemy.com/

* * *

![](https://colibri-engine.com/assets/img/brand/logo_animated.gif)
